summaryrefslogtreecommitdiffstats
path: root/src/gtkmm2-test.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/gtkmm2-test.cpp')
-rw-r--r--src/gtkmm2-test.cpp8
1 files changed, 5 insertions, 3 deletions
diff --git a/src/gtkmm2-test.cpp b/src/gtkmm2-test.cpp
index d92177a..f5f1116 100644
--- a/src/gtkmm2-test.cpp
+++ b/src/gtkmm2-test.cpp
@@ -1,5 +1,7 @@
/* This file is part of mingw-cross-env. */
/* See doc/index.html for further information. */
#include <gtkmm/window.h>
#include <gtkmm/main.h>
@@ -9,7 +11,7 @@ int main(int argc, char *argv[])
Gtk::Main g(argc, argv);
Gtk::Window window;
- window.set_title("Test App mingw-cross-env");
+ window.set_title("Test App MXE");
window.set_default_size(200, 200);
window.show_all();
g.run(window);
@@ -1,5 +1,7 @@
-/* This file is part of mingw-cross-env. */
-/* See doc/index.html for further information. */
+/*
+ * This file is part of MXE.
+ * See index.html for further information.
+ */
#include <gtkmm/window.h>
#include <gtkmm/main.h>